@@ -217,7 +217,7 @@ class ServicesCommands(Commands):
             )
 
         if rdm_version()[0] >= 11:
-            steps.extend(self.static_pages())
+            steps.extend(self.rdm_fixtures())
             steps.extend(self.translations())
 
         steps.append(
@@ -249,20 +249,20 @@ class ServicesCommands(Commands):
             CommandStep(
                 cmd=command,
                 env={"PIPENV_VERBOSITY": "-1"},
-                message="Creating fixtures...",
+                message="Creating records fixtures...",
             )
         ]
 
         return steps
 
-    def static_pages(self):
-        """Steps to set up the static pages for the instance."""
-        command = ["pipenv", "run", "invenio", "rdm", "pages", "create"]
+    def rdm_fixtures(self):
+        """Steps to set up the rdm fixtures for the instance."""
+        command = ["pipenv", "run", "invenio", "rdm", "fixtures"]
         steps = [
             CommandStep(
                 cmd=command,
                 env={"PIPENV_VERBOSITY": "-1"},
-                message="Creating static pages...",
+                message="Creating rdm fixtures...",
             )
         ]
 
